import { RestypedBase, RestypedRoute } from 'restyped';
import * as AwsLambda from 'aws-lambda';
import Request from './request';
import Response from './response';
export { Response, Request };
export interface TypedRequest<T extends RestypedRoute> extends Request {
    body: T['body'];
    params: T['params'];
    query: T['query'];
}
export declare type HTTPMethod = 'GET' | 'POST' | 'PUT' | 'PATCH' | 'HEAD' | 'DELETE' | 'OPTIONS';
export interface IAsyncRouter<API extends RestypedBase> {
    route<Path extends keyof API, Method extends HTTPMethod>(path: Path, method: Method, handler: (req: TypedRequest<API[Path][Method]>, res: Response) => Promise<API[Path][Method]['response'] | void>): void;
    get<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['GET']>, res: Response) => Promise<API[Path]['GET']['response'] | void>): void;
    post<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['POST']>, res: Response) => Promise<API[Path]['POST']['response'] | void>): void;
    put<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['PUT']>, res: Response) => Promise<API[Path]['PUT']['response'] | void>): void;
    delete<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['DELETE']>, res: Response) => Promise<API[Path]['DELETE']['response'] | void>): void;
    patch<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['PATCH']>, res: Response) => Promise<API[Path]['PATCH']['response'] | void>): void;
    options<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['OPTIONS']>, res: Response) => Promise<API[Path]['OPTIONS']['response'] | void>): void;
    head<Path extends keyof API>(path: Path, handler: (req: TypedRequest<API[Path]['HEAD']>, res: Response) => Promise<API[Path]['HEAD']['response'] | void>): void;
    wait<Path extends keyof API, Method extends HTTPMethod>(): Promise<API[Path][Method]['response'] | void>;
}
export interface RouterOptions {
    logErrors: boolean;
}
export default function AsyncRouter<APIDef extends RestypedBase>(event: AwsLambda.APIGatewayEvent, context: AwsLambda.APIGatewayEventRequestContext, callback: AwsLambda.ProxyCallback, options?: RouterOptions, proxyName?: string): IAsyncRouter<APIDef>;
