"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Route = require("route-parser");
const request_1 = require("./request");
exports.Request = request_1.default;
const response_1 = require("./response");
exports.Response = response_1.default;
function AsyncRouter(event, context, callback, options, proxyName = 'proxy') {
    let routeMatched = false;
    let promise = null;
    const createAsyncRoute = function (path, method, handler) {
        const route = new Route(path);
        const routeParams = route.match(event.path);
        if (routeMatched || !routeParams || event.httpMethod !== method) {
            return;
        }
        routeMatched = true;
        const req = new request_1.default(event, context, routeParams);
        const res = new response_1.default(callback);
        promise = handler(req, res)
            .then(result => res.send(result))
            .catch(err => res.error(err, options && options.logErrors ? options.logErrors : false));
    };
    return {
        route: createAsyncRoute,
        get: function (path, handler) {
            return createAsyncRoute(path, 'GET', handler);
        },
        post: function (path, handler) {
            return createAsyncRoute(path, 'POST', handler);
        },
        put: function (path, handler) {
            return createAsyncRoute(path, 'PUT', handler);
        },
        delete: function (path, handler) {
            return createAsyncRoute(path, 'DELETE', handler);
        },
        patch: function (path, handler) {
            return createAsyncRoute(path, 'PATCH', handler);
        },
        options: function (path, handler) {
            return createAsyncRoute(path, 'OPTIONS', handler);
        },
        head: function (path, handler) {
            return createAsyncRoute(path, 'HEAD', handler);
        },
        wait: function () {
            if (!routeMatched) {
                const res = new response_1.default(callback);
                res.status(404).send();
                return Promise.resolve(null);
            }
            return promise;
        }
    };
}
exports.default = AsyncRouter;
//# sourceMappingURL=index.js.map