import * as AwsLambda from 'aws-lambda';
export default class Request {
    private event;
    private context;
    private routeParams;
    constructor(event: AwsLambda.APIGatewayEvent, context: AwsLambda.APIGatewayEventRequestContext, routeParams?: {
        [name: string]: string;
    });
    /**
     * Gets the query string parameters from the event.
     *
     * @return {Object}
     * An object containing all the query string parameters.
     */
    readonly query: {
        [name: string]: string;
    };
    /**
     * Returns the inputted pathParameters from the event object.
     *
     * @return {Object}
     * The path parameters object.
     */
    readonly params: {
        [name: string]: string;
    };
    /**
     * Gets the JSON parsed body from the request. If the body is not parse-able an empty object is
     * returned.
     *
     * @return {Object}
     * JSON parsed body input.
     */
    readonly body: any;
    /**
     * Gets the cognito authorizer claims.
     *
     * @return {Object}
     * The lambda context object
     */
    readonly claims: {
        [name: string]: string;
    };
    /**
     * Gets the whole lambda context object.
     *
     * @return {Object}
     * The lambda context object
     */
    readonly contextObject: AwsLambda.APIGatewayEventRequestContext;
    /**
     * Gets the whole lambda event object.
     *
     * @return {Object}
     * The lambda event object
     */
    readonly eventObject: AwsLambda.APIGatewayEvent;
    /**
     * Gets the stage variables from the event object.
     *
     * @return {Object}
     * Returns the stage variables if they are available. Will return an empty object if not.
     */
    readonly stageVariables: {
        [name: string]: string;
    };
    /**
     * Returns the raw body sent in the request without it being JSON parsed.
     *
     * @return {string}
     * The raw body from the request.
     */
    readonly rawBody: string;
    /**
     * Return the headers object or an empty object from the event.
     *
     * @return {Object}
     * The headers from the request
     */
    readonly headers: {
        [name: string]: string;
    };
}
