import { ProxyCallback } from 'aws-lambda';
export default class Response {
    readonly sent: boolean;
    private _sent;
    private _callback;
    private _statusCode;
    private _base64Encoded;
    private _body;
    private _headers;
    constructor(callback: ProxyCallback, enableCors?: boolean);
    /**
     * Set status `code`.
     *
     * @param code
     */
    status(code: number): Response;
    base64Encoded(value: boolean): Response;
    /**
     * Set header `field` to `val`, or pass
     * an object of header fields.
     *
     * Examples:
     *
     *    res.set('Foo', ['bar', 'baz']);
     *    res.set('Accept', 'application/json');
     *
     * Aliased as `res.header()`.
     */
    set(field: string, value: string | number | boolean): Response;
    header(field: string, value: string | number | boolean): Response;
    /**
     * Get value for header `field`.
     *
     * @param field
     */
    get(field: string): string | number | boolean;
    contentType(type: string): Response;
    /**
     * Set the location header to `url`.
     *
     * The given `url` can also be the name of a mapped url, for
     * example by default express supports "back" which redirects
     * to the _Referrer_ or _Referer_ headers or "/".
     *
     * Examples:
     *
     *    res.location('/foo/bar').;
     *    res.location('http://example.com');
     *
     * @param url
     */
    location(url: string): Response;
    /**
     * Redirect to the given `url` with optional response `status`
     * defaulting to 302.
     *
     * The resulting `url` is determined by `res.location()`, so
     * it will play nicely with mounted apps, relative paths,
     * `"back"` etc.
     *
     * Examples:
     *
     *    res.redirect('/foo/bar');
     *    res.redirect('http://example.com');
     *    res.redirect(301, 'http://example.com');
     *    res.redirect('http://example.com', 301);
     *    res.redirect('../login'); // /blog/post/1 -> /blog/login
     */
    redirect(url: any, status?: number): void;
    error(error: Error, logErrors: boolean): void;
    send(body?: any): void;
}
